@@ -131,10 +131,9 @@ fn clear_on_del(mut commands: Commands, kbd: Res<Input<KeyCode>>) {
 }
 
 /// Transition back to menu on pressing Escape
-/// (here we show how to perform a state transition using ResMut)
-fn back_to_menu_on_esc(mut next: ResMut<NextState<GameState>>, kbd: Res<Input<KeyCode>>) {
+fn back_to_menu_on_esc(mut commands: Commands, kbd: Res<Input<KeyCode>>) {
     if kbd.just_pressed(KeyCode::Escape) {
-        *next = NextState(GameState::MainMenu);
+        commands.insert_resource(NextState(GameState::MainMenu));
     }
 }
 
@@ -234,8 +233,8 @@ fn butt_exit(mut ev: EventWriter<AppExit>) {
 }
 
 /// Handler for the Enter Game button
-/// (here we show how to perform a state transition using Commands)
 fn butt_game(mut commands: Commands) {
+    // queue state transition
     commands.insert_resource(NextState(GameState::InGame));
 }
 
